%Conjugate gradient direction update
%Using fletcher-reeves iteration
%
%
function [pk,rk] = amsopt_cgfl_dirupdate(fpnt,x,dx,N,fopt,has_old,pk_old,rk_old,solpars)

[grad,crv] = int_gradient(fpnt,x,dx,fopt,N);

if(~has_old)
    %This is the first iteration
    rk = -grad;
    pk = -grad;
else
    %This is a subsequent iteration
    rk = -grad;
    Bk = dot(rk,rk)/dot(rk_old,rk_old);
    pk = rk + Bk*pk_old;
end

return

%Obtain current gradient (and curvature along gradient direction, while I'm
%at it
function [grad,crv] = int_gradient(fpnt,x,dx,fopt,N)

f0 = fpnt(x,fopt);
fp = zeros(N,1);
fm = zeros(N,1);

for I = 1:N
    [xp, xm] = int_xvariant_a(x,dx,I);
    fp(I) = fpnt(xp,fopt);
    fm(I) = fpnt(xm,fopt);
end

grad = zeros(N,1);

for I = 1:N
    grad(I) = (fp(I) - fm(I))/2/dx;
end

xp1 = x-grad./norm(grad).*dx;
xp2 = x-2.0.*grad./norm(grad).*dx;
fp1 = fpnt(xp1,fopt);
fp2 = fpnt(xp2,fopt);
crv = (fp2+f0-2*fp1)/dx/dx;

return

function [xp,xm] = int_xvariant_a(x,dx,I)
    xp = x;
    xm = x;
    if(I>=1&&I<=size(x,1))
        xp(I) = xp(I) + dx;
        xm(I) = xm(I) - dx;
    end
return