%Conjugate gradient descent algorithm
%Unconstrained optimization of scalar function f(x,fopt) for column vector
%parameter x.
%

function [xs,valid] = amsopt_cgls(fpnt,x0,fopt,N,solpars)

solpars = int_defaults(solpars);
solpars.fdesc = 1; %Force descent using wolfe linesearch solver
dx = solpars.dx;
verbose = solpars.verbose;

x = x0;
xold = x0.*1E4;
I = 1;
qf = 0;
while(I<solpars.maxiter&&qf==0)
    %get CG search direction
    if(I==1)
        has_old = 0;
        pk = zeros(N,1);
        rk = zeros(N,1);
        [pk,rk] = amsopt_cgfl_dirupdate(fpnt,x,dx,N,fopt,has_old,pk,rk,solpars);
    else
        has_old = 1;
        [pk,rk] = amsopt_cgfl_dirupdate(fpnt,x,dx,N,fopt,has_old,pk,rk,solpars);
    end
    
    if(verbose>1)
        f0 = fpnt(x,fopt);
        fprintf('I:%d |r|=%1.6g |p| = %1.6g f(x)=%1.6g\n',I,norm(rk),norm(pk),f0);
    end
    
    if(norm(rk)<solpars.vtol)
        %We are converged
        xs = x;
        valid = 1;
        qf = 1;
    end
    
    if(solpars.use_reltol)
        %Test relative tolerance
        if(norm(xold-x)<solpars.reltol)
            %We are converged
            xs = x;
            valid = 1;
            qf=1;
        end
    end
    xold = x;
    
    %perform line-search in CG search direction
    [x,a,jnk] = amsopt_lnsrch_wolfe(fpnt,x,dx,fopt,pk,solpars);
    
    I = I + 1;
end

if(I>=solpars.maxiter)
    xs = x;
    valid = 0; %we are not converged
end

return


function solpars = int_defaults(solpars)

if(~isfield(solpars,'dx'))
    solpars.dx = 1E-7;
end

if(~isfield(solpars,'maxiter'))
    solpars.maxiter = 10000;
end

if(~isfield(solpars,'verbose'))
    solpars.verbose = 0;
end

if(~isfield(solpars,'vtol'))
    solpars.vtol = 1E-4;
end

if(~isfield(solpars,'use_reltol'))
    solpars.use_reltol = 1;
end

if(~isfield(solpars,'reltol'))
    solpars.reltol = 1E-8;
end

return