%Newton-Rhapson Extrema Solver (v2)

function [xs, valid] = amsopt_newton_v2(fpnt,x0,N,fopt,solpars)

xs = x0;
valid = -2;

solpars = int_defaults(solpars);
verbose = solpars.verbose;
dx = solpars.dx;


I = 0;
qf = 0;
x = x0;
xold = x0.*1E15;

while(I<solpars.maxiter&&qf==0)
    
    %I. Update search direction
    [p, hessflg, hess] = amsopt_newtondirupdate(fpnt,x,dx,N,fopt,solpars);
    
    if(norm(p)<solpars.vtol)
        %we are converged!
        xs = x;
        qf = 1;
        valid = 1;
    end
    
    %II. Perform linesearch
    if(~solpars.use_alphastep)
        %a full Wolfe-condition line-search
        [x, a, flg] = amsopt_lnsrch_wolfe(fpnt,x,dx,fopt,p,solpars);
    else
        %an alternative simple newton-method step
        x = x + p.*solpars.alpha;
    end
    %III. Test convergence
    if(solpars.use_reltol)
        if(norm(x-xold)<solpars.reltol)
            %We have converged.
            xs = x;
            qf = 1;
            valid = 1;
        end
    end
    
    if(verbose>0)
        f0 = fpnt(x,fopt);
        fprintf('I:%d |p| = %1.6g f(x)=%1.6g\n',I,norm(p),f0);
    end
    
    xold = x;
    I = I + 1;
end

if(I>=solpars.maxiter)
    %Didn't converge in maximum iterations
    xs = x;
    valid = 0;
end



return


function solpars = int_defaults(solpars)

if(~isfield(solpars,'verbose'))
    solpars.verbose = 0;
end

if(~isfield(solpars,'dx'))
    solpars.dx = 1E-7;
end

if(~isfield(solpars,'maxiter'))
    solpars.maxiter = 10000;
end

if(~isfield(solpars,'vtol'))
    solpars.vtol = 1E-5;
end

if(~isfield(solpars,'use_reltol'))
    solpars.use_reltol = 1;
end

if(~isfield(solpars,'reltol'))
    solpars.reltol = 1E-8;
end

if(~isfield(solpars,'fdesc'))
    solpars.fdesc = 0;
end

if(~isfield(solpars,'dettol'))
    solpars.dettol = 1E-5;
end

if(~isfield(solpars,'condtol'))
    solpars.condtol = 1E-15;
end

if(~isfield(solpars,'use_alphastep'))
    solpars.use_alphastep = 0;
end

if(~isfield(solpars,'alpha'))
    solpars.alpha = 0.5;
end

return