%Dynamics for state evolution of thrusting spacecraft in solar gravity
function xdot = amsorb_top2_fdyn1(t,xx,pars)
mu = pars.mu;
Nazel = 3; %number of azimuth/elevation direction control points per burn
azl = pars.azl; %azimuth list for spacecraft thrust vector direction
ell = pars.ell; %elevation list for spacecraft thrust vector direction
tt0 = pars.tt0; %time to terminate thrusting for first burn
tt1 = pars.tt1; %time to begin thrusting for second burn
T = pars.T; %normalized thrust (thrust/initial mass)
Isp = pars.Isp; %sec Isp for spacecraft
t0 = pars.t0;
tf = pars.tf;

%m is normalized to initial spacecraft mass
%xx = [xd,yd,zd,x,y,z,m]
xd = xx(1);
yd = xx(2);
zd = xx(3);
x = xx(4);
y = xx(5);
z = xx(6);
m = xx(7);

%basis
br = [x,y,z]'; br = br./norm(br);
bv = [xd,yd,zd]'; bv = bv./norm(bv); %velocity prograde vector
bh = cross(br,bv); bh = bh./norm(bh); %angular momentum vector
bvp = cross(bv,bh); %normal to velocity vector
bth = cross(bh,br); %theta vector

%calculate thrust control vectors
for I = 1:2*Nazel
    that{I} = [cos(ell(I))*cos(az(I));cos(ell(I))*sin(az(I));sin(ell(I))];
end
%calculate thrust vector (3 az-el points for each span)
vt = [0,0,0]';
tsps = t0;
tspe = t0+(tt0-t0)/2;
if(t>=tsps&&t<tspe)
    v1 = that{1}(1)*bvp+that{1}(2)*bv+that{1}(3)*bh; %(0 1 0 is prograde)
    v2 = that{2}(1)*bvp+that{2}(2)*bv+that{2}(3)*bh;
    f1 = (t-tsps)/(tspe-tsps);
    f2 = 1-f1;
    vt = v1.*f1+v2.*f2;
    if(norm(vt)==0)
        vt = [0,0,0]';
    else
        vt = vt./norm(vt);
    end
end
tsps = t0+(tt0-t0)/2;
tspe = t0+2*(tt0-t0)/2;
if(t>=tsps&&t<tspe)
    v1 = that{2}(1)*bvp+that{2}(2)*bv+that{2}(3)*bh; %(0 1 0 is prograde)
    v2 = that{3}(1)*bvp+that{3}(2)*bv+that{3}(3)*bh;
    f1 = (t-tsps)/(tspe-tsps);
    f2 = 1-f1;
    vt = v1.*f1+v2.*f2;
    if(norm(vt)==0)
        vt = [0,0,0]';
    else
        vt = vt./norm(vt);
    end
end
tsps = tf-2*(tf-tt1)/2;
tspe = tf-1*(tf-tt1)/2;
if(t>=tsps&&t<tspe)
    v1 = that{4}(1)*bvp+that{4}(2)*bv+that{4}(3)*bh; %(0 1 0 is prograde)
    v2 = that{5}(1)*bvp+that{5}(2)*bv+that{5}(3)*bh;
    f1 = (t-tsps)/(tspe-tsps);
    f2 = 1-f1;
    vt = v1.*f1+v2.*f2;
    if(norm(vt)==0)
        vt = [0,0,0]';
    else
        vt = vt./norm(vt);
    end
end 
tsps = tf-1*(tf-tt1)/2;
tspe = tf-0*(tf-tt1)/2;
if(t>=tsps&&t<tspe)
    v1 = that{5}(1)*bvp+that{5}(2)*bv+that{5}(3)*bh; %(0 1 0 is prograde)
    v2 = that{6}(1)*bvp+that{6}(2)*bv+that{6}(3)*bh;
    f1 = (t-tsps)/(tspe-tsps);
    f2 = 1-f1;
    vt = v1.*f1+v2.*f2;
    if(norm(vt)==0)
        vt = [0,0,0]';
    else
        vt = vt./norm(vt);
    end
end     
 
xdot = zeros(size(x,1),1);


return