%AMS Julian Calendar Date to JD Converter
%Converts calendar year,month,day,hour,minute,second GMT to julian calendar
%day for astrometric calculations.
%
%function [JD, MJD] = ams_juliandate(yr, month, day, hour, minute, sec_b)
function [JD, MJD] = ams_juliandate(yr, month, day, hour, minute, sec_b)

%2000 Jan 1 00:00:00 UT is 2451544.5
%for the MJD = JD - 2400000.5
%The Julian date for CE  2400 January  1 00:00:00.0 UT is
%JD 2597641.500000
%146097 days per 400 years
%The Julian date for CE  2500 January  1 00:00:00.0 UT is
%JD 2634166.500000
%The Julian date for CE  2600 January  1 00:00:00.0 UT is
%JD 2670690.500000
%The Julian date for CE  2700 January  1 00:00:00.0 UT is
%JD 2707214.500000
%The Julian date for CE  2800 January  1 00:00:00.0 UT is
%JD 2743738.500000
%"J2000" refers to the instant of 12h on 1 January 2000, and J1900 refers to the instant of 12h (midday) on 0 January 1900
%So  that would be 2451545.0


JD = 0;
yprime = yr - 2000; %how many yrs since 2000
gfh = floor(yprime/400); %what block of 400 yrs is it?
%Number of days is a 400 yr block (not counting yr 400)
%100 - 3 leap yrs
%303 normal yrs
nday1 = 97*366+303*365;

d1 = gfh*nday1; %base date
%which century within 400 yr block?

%how many days in a century block?
%0th: 0
%1st: +366*25+365*74
%2nd: +366*24+365*75
%3rd: +366*24+365*75
y2 = mod(yprime,400);
cent = floor(y2/100);
d2pa = 0+1;
d2pb = d2pa + 366*25+365*75-1;    %36525
d2pc = d2pb + 366*24+365*76;    %36524
d2pd = d2pc + 366*24+365*76;    %36524
                                %36524
        
if(cent==0)
    d2p = d2pa;
elseif(cent==1)
    d2p = d2pb;
elseif(cent==2)
    d2p = d2pc;
elseif(cent==3)
    d2p = d2pd;
else
    fprintf('Warning! Something screwy is going on with century count.\n');
end

d2 = d1 + d2p; %days up to the present century
%which yr in century, and how many leap yrs have passed?
y3 = mod(y2,100); %yr within a century
nly = floor(y3/4);
d3p = nly*366+(y3-nly)*365;
d3 = d2 + d3p; %days up to the start of the present yr

%kluge to get rid of extra day every leap year:
if(mod(yr,400)==0)
    d3 = d3 - 1;
else
    if(~(mod(yr,100)==0))
        if(mod(yr,4)==0)
            d3 = d3 - 1;
        end
    end
end

%how many days have passed since beginning of month in yr
md_nly = [31,28,31,30,31,30,31,31,30,31,30,31];
md_ly = [31,29,31,30,31,30,31,31,30,31,30,31];
md_nly_b = [0;31;59;90;120;151;181;212;243;273;304;334]';
md_ly_b = [0;31;60;91;121;152;182;213;244;274;305;335]';
%is this a leap-yr?
if(y3 == 0)
    if(y2 == 0)
        %yes
        isleap = 1;
    else
        %no
        isleap = 0;
    end
else
    if(mod(y3,4)==0)
        %yes
        isleap = 1;
    else
        isleap = 0;
    end
end

if(isleap==1)
    d4 = d3 + md_ly_b(month);
else
    d4 = d3 + md_nly_b(month);
end

d5 = d4 + day-1;

%hours, minutes, and seconds

d6 = d5 + hour/24.0 + minute/24.0/60.0 + sec_b/24.0/3600.0;

%quick fix to a problem: I am losing 1 day every 400 years for some reason


JD = d6 + 2451544.5;
MJD = JD - 2400000.5;

return
