%Generates initial conditions for optimization problem, assuming that you
%can thrust as if you have arbitrarily high thrust to complete an impulsive
%maneuver.

function optpars = ams_top2_gen_ics(ppars)

t0 = ppars.t0;
tf = ppars.tf;
r0 = ppars.r0;
v0 = ppars.v0;
rf = ppars.rf; %the target, not necessarily what will be acheived
vf = ppars.vf; %the target, not necessarily what will be acheived
mu = ppars.mu;
Nt = ppars.Nt; %number of time increments to use for integration
Nazel = ppars.Nazel; %number of azimuth/elevation control points to use
T = ppars.T; %thrust magnitude (acceleration at initial mass, m/sec^2)
Isp = ppars.Isp; %specific impulse (sec)
m = ppars.m0; %mass (fraction of initial mass)

optpars = struct();
%bvalid  - given the thrust and dVs, is it likely that a solution can be found? 
%tt0 = optpars.tt0; %time after start to stop initial burn
%ttf = optpars.ttf; %time before finish to begin thrusting
%azlst1 = optpars.azlst1; %thrust pointing list
%ellst1 = optpars.ellst1;
%azlst2 = optpars.azlst2;
%ellst2 = optpars.ellst2;


%figure out which trajectory to use
[v1_sw, v2_sw, v1_lw, v2_lw, valid] = amsorb_Gaussp_b(r0,rf,tf-t0,mu);
dV1 = norm(v0-v1_sw)+norm(vf-v2_sw);
dV2 = norm(v0-v1_lw)+norm(vf-v2_lw);
if(dV1<dV2)
    vt1 = v1_sw;
    vt2 = v2_sw;
    dv1 = vt1-v0;
    dv2 = vf-vt2;
else
    vt1 = v1_lw;
    vt2 = v2_lw;
    dv1 = vt1-v0;
    dv2 = vf-vt2;
end

b1 = [1;0;0];
b2 = [0;1;0];
b3 = [0;0;1];

%Figure out azimuth-elevation for each deltaV and initialize az-el lists
[az1,el1] = ams_vector_to_azel(dv1,b1,b2,b3);
[az2,el2] = ams_vector_to_azel(dv2,b1,b2,b3);
azlst1 = ones(1,Nazel).*az1;
ellst1 = ones(1,Nazel).*el1;
azlst2 = ones(1,Nazel).*az2;
ellst2 = ones(1,Nazel).*el2;
tt0 = norm(dv1)/T*m;
m2 = m*exp(-norm(dv1)/Isp/9.8);
ttf = norm(dv2)/T*m2;
if((tt0+ttf)>(tf-t0))
    bvalid = 0;
else
    bvalid = 1;
end

optpars.azlst1 = azlst1;
optpars.ellst1 = ellst1;
optpars.azlst2 = azlst2;
optpars.ellst2 = ellst2;
optpars.bvalid = bvalid;
optpars.tt0 = tt0;
optpars.ttf = ttf;


return