%Function to generate the a patched-conic solar system structure containing
%solar system objects and their orbits. The object is in the amstree
%format, with a cell-list of object structs, and substructures containing
%orbit, property, and display information.
%
%function solarsys = amsorb_generatesolarsys()
function solarsys = amsorb_generatesolarsys()

%%%%%%%%%%%%%%%%%%
%%Some Constants%%
%%%%%%%%%%%%%%%%%%
G = 6.67408E-11; %N-m^2/kg^2;
AU = 149597870700; %m in an AU
cty = 100*365.25*24*3600; %sec in a century
rad = pi/180; %conv deg to radians
day = 24*3600; %sec in a day

solarsys = struct();
solarsys.class = 'solarsys'; %solar system class
solarsys.objs = {};
solarsys.rootobj = -1; %no root object yet

%Global display characteristics
globaldisp = struct();
globaldisp.bgcolor = [0,0,0];
globaldisp.scale = 1; %scales all objects to display an orrery model
globaldisp.ovr_displaysphere = 0;

solarsys.globaldisp = globaldisp;

solarsys.epochname = 'J2000';
solarsys.epoch = 2451545.0; %J2000 epoch in JD (Julian calendar days)
%epoch for all planet orbits
epoch = 2451545.0; %J2000 epoch in JD (Julian calendar days)
epochmax = 2469806.50; %after this JD, stop evolving orbits (not accurate beyond this point)
epochmin = 2378496.50; %before this JD, stop evolving orbits (not accurate before this date)

solarsys.epochmax = epochmax;
solarsys.epochmin = epochmin;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Sun: Generate Sun's Characteristics%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sun = amstree_newtreeobj();
sun.class = 'star';
sun.name = 'sun';

%Sun's property characteristics
prop = struct();
prop.mass = 1.98855E30; %kg
prop.radius = 696342000; %m

sun.prop = prop;

%Sun's display property characteristics
disp = struct();
disp.displaycol = [1,1,0];
disp.displaysphere = 1;
disp.displaycursor = 1;

sun.disp = disp;

%Sun's orbit properties
orbit = struct();
orbit.type = 'fixed';
orbit.location = [0,0,0]';

sun.orbit = orbit;
%Close sun definition and attach to tree
solarsys = amstree_attachroot(solarsys,sun);
%%%%%%%%%%
%End: Sun%
%%%%%%%%%%

%%%%%%%%%
%Mercury%
%%%%%%%%%
mercury = amstree_newtreeobj();
mercury.class = 'planet';
mercury.name = 'mercury';

%Mercury's property characteristics
prop = struct();
prop.mass = 3.3011E23; %kg
prop.radius = 2439700; %m

mercury.prop = prop;

%Mercury's display property characteristics
disp = struct();
disp.displaycol = [0.5,0.5,0.5];
disp.displaysphere = 1;
disp.displaycursor = 1;

mercury.disp = disp;

%Sun's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 0.38709927*AU;                    %m          Semi-maj Axis
orbit.adot = 0.00000037*AU/cty;             %m/sec
orbit.e =  0.20563593;                      %ND         Eccentricity
orbit.edot =  0.00001906/cty;               %1/sec 
orbit.inc = 7.00497902*rad;                 %rad        Inclination
orbit.incdot = -0.00594749*rad/cty;         %rad/sec
orbit.L = 252.25032350*rad;                 %rad        Mean longitude
orbit.Ldot = 149472.67411175*rad/cty;       %rad/sec   
orbit.lperi = 77.45779628*rad;              %rad        Long of pericenter
orbit.lperidot =  0.16047689*rad/cty;       %rad/sec   
orbit.Omega = 48.33076593*rad;              %rad        Long of ascending node
orbit.Omegadot = -0.12534081*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
mercury.orbit = orbit;
%Close sun definition and attach to tree
solarsys = amstree_attachobj(solarsys,mercury,'sun');

%%%%%%%%%%%%%%
%End: Mercury%
%%%%%%%%%%%%%%


%%%%%%%
%Venus%
%%%%%%%
venus = amstree_newtreeobj();
venus.class = 'planet';
venus.name = 'venus';

%Venus's property characteristics
prop = struct();
prop.mass = 4.8675E24; %kg
prop.radius = 6051800; %m

venus.prop = prop;

%Venus's display property characteristics
disp = struct();
disp.displaycol = [0.5,0.5,0.1];
disp.displaysphere = 1;
disp.displaycursor = 1;

venus.disp = disp;

%Venus's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 0.72333566*AU;                    %m          Semi-maj Axis
orbit.adot = 0.00000390*AU/cty;             %m/sec
orbit.e =  0.00677672;                      %ND         Eccentricity
orbit.edot =  -0.00004107/cty;               %1/sec 
orbit.inc = 3.39467605*rad;                 %rad        Inclination
orbit.incdot = -0.00078890*rad/cty;         %rad/sec
orbit.L = 181.97909950*rad;                 %rad        Mean longitude
orbit.Ldot = 58517.81538729*rad/cty;       %rad/sec   
orbit.lperi = 131.60246718*rad;              %rad        Long of pericenter
orbit.lperidot =  0.00268329*rad/cty;       %rad/sec  
orbit.Omega = 76.67984255*rad;              %rad        Long of ascending node
orbit.Omegadot = -0.27769418*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
venus.orbit = orbit;

%Close Venus definition and attach to tree
solarsys = amstree_attachobj(solarsys,venus,'sun');

%%%%%%%%%%%%
%End: Venus%
%%%%%%%%%%%%

%%%%%%%
%Earth%
%%%%%%%

%Technically, this is for the Earth-Moon barycenter, but I'll fix it later.
%For now, I just want good approximate positions for each object
earth = amstree_newtreeobj();
earth.class = 'planet';
earth.name = 'earth';

%Earth's property characteristics
prop = struct();
prop.mass = 5.97237E24; %kg
prop.radius = 6371000; %m

earth.prop = prop;

%Earth's display property characteristics
disp = struct();
disp.displaycol = [0,0,1];
disp.displaysphere = 1;
disp.displaycursor = 1;

earth.disp = disp;

%Earth's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 1.00000261*AU;                    %m          Semi-maj Axis
orbit.adot = 0.00000562*AU/cty;             %m/sec
orbit.e =  0.01671123;                      %ND         Eccentricity
orbit.edot =  -0.00004392/cty;               %1/sec 
orbit.inc = -0.00001531*rad;                 %rad        Inclination
orbit.incdot = -0.01294668*rad/cty;         %rad/sec
orbit.L = 100.46457166*rad;                 %rad        Mean longitude
orbit.Ldot = 35999.37244981*rad/cty;       %rad/sec   
orbit.lperi = 102.93768193*rad;              %rad        Long of pericenter
orbit.lperidot =  0.32327364*rad/cty;       %rad/sec 
orbit.Omega = 0*rad;              %rad        Long of ascending node
orbit.Omegadot = 0*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
earth.orbit = orbit;

%Close Earth definition and attach to tree
solarsys = amstree_attachobj(solarsys,earth,'sun');

%%%%%%%%%%%%
%End: Earth%
%%%%%%%%%%%%

%%%%%%
%Mars%
%%%%%%

mars = amstree_newtreeobj();
mars.class = 'planet';
mars.name = 'mars';

%Mars's property characteristics
prop = struct();
prop.mass = 6.4171E23; %kg
prop.radius = 3389500; %m

mars.prop = prop;

%Mars's display property characteristics
disp = struct();
disp.displaycol = [0.8,0,0];
disp.displaysphere = 1;
disp.displaycursor = 1;

mars.disp = disp;

%Mars's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 1.52371034*AU;                    %m          Semi-maj Axis
orbit.adot = 0.00001847*AU/cty;             %m/sec
orbit.e =  0.09339410;                      %ND         Eccentricity
orbit.edot =  -0.00007882/cty;               %1/sec 
orbit.inc = 1.84969142*rad;                 %rad        Inclination
orbit.incdot = -0.00813131*rad/cty;         %rad/sec
orbit.L = -4.55343205*rad;                 %rad        Mean longitude
orbit.Ldot = 19140.30268499*rad/cty;       %rad/sec   
orbit.lperi = -23.94362959*rad;              %rad        Long of pericenter
orbit.lperidot =  0.44441088*rad/cty;       %rad/sec
orbit.Omega = 49.55953891*rad;              %rad        Long of ascending node
orbit.Omegadot = -0.29257343*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
mars.orbit = orbit;

%Close Mars definition and attach to tree
solarsys = amstree_attachobj(solarsys,mars,'sun');

%%%%%%%%%%%
%End: Mars%
%%%%%%%%%%%

%%%%%%%%%
%Jupiter%
%%%%%%%%%

jupiter = amstree_newtreeobj();
jupiter.class = 'planet';
jupiter.name = 'jupiter';

%Jupiter's property characteristics
prop = struct();
prop.mass = 1.8986E27; %kg
prop.radius = 69911000; %m

jupiter.prop = prop;

%Jupiter's display property characteristics
disp = struct();
disp.displaycol = [0.9,0.8,0.7];
disp.displaysphere = 1;
disp.displaycursor = 1;

jupiter.disp = disp;

%Jupiter's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 5.20288700*AU;                    %m          Semi-maj Axis
orbit.adot = -0.00011607*AU/cty;             %m/sec
orbit.e =  0.04838624;                      %ND         Eccentricity
orbit.edot =  -0.00013253/cty;               %1/sec 
orbit.inc = 1.30439695*rad;                 %rad        Inclination
orbit.incdot = -0.00183714*rad/cty;         %rad/sec
orbit.L = 34.39644051*rad;                 %rad        Mean longitude
orbit.Ldot = 3034.74612775*rad/cty;       %rad/sec   
orbit.lperi = 14.72847983*rad;              %rad        Long of pericenter
orbit.lperidot =  0.21252668*rad/cty;       %rad/sec
orbit.Omega = 100.47390909*rad;              %rad        Long of ascending node
orbit.Omegadot = 0.20469106*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
jupiter.orbit = orbit;

%Close Jupiter definition and attach to tree
solarsys = amstree_attachobj(solarsys,jupiter,'sun');

%%%%%%%%%%%%%%
%End: Jupiter%
%%%%%%%%%%%%%%

%%%%%%%%
%Saturn%
%%%%%%%%

saturn = amstree_newtreeobj();
saturn.class = 'planet';
saturn.name = 'saturn';

%Saturn's property characteristics
prop = struct();
prop.mass = 5.6835E26; %kg
prop.radius = 58232000; %m

saturn.prop = prop;

%Saturn's display property characteristics
disp = struct();
disp.displaycol = [0.8,0.8,0.5];
disp.displaysphere = 1;
disp.displaycursor = 1;

saturn.disp = disp;

%Saturn's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 9.53667594*AU;                    %m          Semi-maj Axis
orbit.adot = -0.00125060*AU/cty;             %m/sec
orbit.e =  0.05386179;                      %ND         Eccentricity
orbit.edot =  -0.00050991/cty;               %1/sec 
orbit.inc = 2.48599187*rad;                 %rad        Inclination
orbit.incdot = 0.00193609*rad/cty;         %rad/sec
orbit.L = 49.95424423*rad;                 %rad        Mean longitude
orbit.Ldot = 1222.49362201*rad/cty;       %rad/sec   
orbit.lperi = 92.59887831*rad;              %rad        Long of pericenter
orbit.lperidot =  -0.41897216*rad/cty;       %rad/sec 
orbit.Omega = 113.66242448*rad;              %rad        Long of ascending node
orbit.Omegadot = -0.28867794*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
saturn.orbit = orbit;

%Close Saturn definition and attach to tree
solarsys = amstree_attachobj(solarsys,saturn,'sun');

%%%%%%%%%%%%%
%End: Saturn%
%%%%%%%%%%%%%

%%%%%%%%
%Uranus%
%%%%%%%%

uranus = amstree_newtreeobj();
uranus.class = 'planet';
uranus.name = 'uranus';

%Uranus's property characteristics
prop = struct();
prop.mass = 8.6810E25; %kg
prop.radius = 25362000; %m

uranus.prop = prop;

%Uranus's display property characteristics
disp = struct();
disp.displaycol = [0.4,0.4,0.8];
disp.displaysphere = 1;
disp.displaycursor = 1;

uranus.disp = disp;

%Uranus's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 19.18916464*AU;                    %m          Semi-maj Axis
orbit.adot = -0.00196176*AU/cty;             %m/sec
orbit.e =  0.04725744;                      %ND         Eccentricity
orbit.edot =  -0.00004397/cty;               %1/sec 
orbit.inc = 0.77263783*rad;                 %rad        Inclination
orbit.incdot = -0.00242939*rad/cty;         %rad/sec
orbit.L = 313.23810451*rad;                 %rad        Mean longitude
orbit.Ldot = 428.48202785*rad/cty;       %rad/sec   
orbit.lperi = 170.95427630*rad;              %rad        Long of pericenter
orbit.lperidot =  0.40805281*rad/cty;       %rad/sec   
orbit.Omega = 74.01692503*rad;              %rad        Long of ascending node
orbit.Omegadot = 0.04240589*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
uranus.orbit = orbit;

%Close Uranus definition and attach to tree
solarsys = amstree_attachobj(solarsys,uranus,'sun');

%%%%%%%%%
%Neptune%
%%%%%%%%%

neptune = amstree_newtreeobj();
neptune.class = 'planet';
neptune.name = 'neptune';

%Neptune's property characteristics
prop = struct();
prop.mass = 1.0243E26; %kg
prop.radius = 24622000; %m

neptune.prop = prop;

%Neptune's display property characteristics
disp = struct();
disp.displaycol = [0.05,0,0.8];
disp.displaysphere = 1;
disp.displaycursor = 1;

neptune.disp = disp;

%Neptune's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 30.06992276*AU;                    %m          Semi-maj Axis
orbit.adot = 0.00026291*AU/cty;             %m/sec
orbit.e =  0.00859048;                      %ND         Eccentricity
orbit.edot =  -0.00005105/cty;               %1/sec 
orbit.inc = 1.77004347*rad;                 %rad        Inclination
orbit.incdot = 0.00035372*rad/cty;         %rad/sec
orbit.L = -55.12002969*rad;                 %rad        Mean longitude
orbit.Ldot = 218.45945325*rad/cty;       %rad/sec   
orbit.lperi = 44.96476227*rad;              %rad        Long of pericenter
orbit.lperidot =  -0.32241464*rad/cty;       %rad/sec   
orbit.Omega = 131.78422574*rad;              %rad        Long of ascending node
orbit.Omegadot = -0.00508664*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
neptune.orbit = orbit;

%Close Neptune definition and attach to tree
solarsys = amstree_attachobj(solarsys,neptune,'sun');

%%%%%%%
%Pluto%
%%%%%%%

pluto = amstree_newtreeobj();
pluto.class = 'planet';
pluto.name = 'pluto';

%Pluto's property characteristics
prop = struct();
prop.mass = 1.303E22; %kg
prop.radius = 1187000; %m

pluto.prop = prop;

%Pluto's display property characteristics
disp = struct();
disp.displaycol = [0.5,0.3,0.2];
disp.displaysphere = 1;
disp.displaycursor = 1;

pluto.disp = disp;

%Pluto's orbit properties
orbit = struct();
orbit.type = 'kepler_rate';
orbit.a = 39.48211675*AU;                    %m          Semi-maj Axis
orbit.adot = -0.00031596*AU/cty;             %m/sec
orbit.e =  0.24882730;                      %ND         Eccentricity
orbit.edot =  0.00005170/cty;               %1/sec 
orbit.inc = 17.14001206*rad;                 %rad        Inclination
orbit.incdot = 0.00004818*rad/cty;         %rad/sec
orbit.L = 238.92903833*rad;                 %rad        Mean longitude
orbit.Ldot = 145.20780515*rad/cty;       %rad/sec   
orbit.lperi = 224.06891629*rad;              %rad        Long of pericenter
orbit.lperidot =  -0.04062942*rad/cty;       %rad/sec   
orbit.Omega = 110.30393684*rad;              %rad        Long of ascending node
orbit.Omegadot = -0.01183482*rad/cty;        %rad/sec
orbit.epoch = epoch;                        %JD - epoch of orbit data
orbit.epochmax = epochmax;
orbit.epochmin = epochmin;
pluto.orbit = orbit;

%Close Pluto definition and attach to tree
solarsys = amstree_attachobj(solarsys,pluto,'sun');

%%%%%%%%%%%%%%%%
%%Earth's Moon%%
%%%%%%%%%%%%%%%%

emoon = amstree_newtreeobj();
emoon.class = 'planet';
emoon.name = 'moon';

%Moon's property characteristics
prop = struct();
prop.mass = 7.342E22; %kg
prop.radius = 1737100; %m

emoon.prop = prop;

%Moon's display property characteristics
disp = struct();
disp.displaycol = [0.5,0.5,0.5];
disp.displaysphere = 1;
disp.displaycursor = 1;

emoon.disp = disp;

%Moon's orbit properties
orbit = struct();
orbit.type = 'kepler_JPLmoon';
orbit.a = 384400*1E3;                    %m      Semi-maj Axis
orbit.e = 0.0554;                        %ND     Eccentricity
orbit.lomega = 318.15*rad;               %rad    arg of periapsis
orbit.M = 135.27*rad;                    %rad    mean anomaly
orbit.inc = 5.16*rad;                    %rad    inclination
orbit.Omega = 13.176358*rad;             %rad    long of asc. node
orbit.Omegadot = 13.176358*rad/day;      %rad/sec long of asc. node rate
orbit.epoch = 2451545.5; %Epoch 2000 Jan 1.50 TT (JD)

%Other information is provided to make more accurate calculations, but I'm
%skipping it for now
emoon.orbit = orbit;

%Close Moon definition and attach to tree
solarsys = amstree_attachobj(solarsys,emoon,'earth');

%%%%%%%
%Ceres%
%%%%%%%

ceres = amstree_newtreeobj();
ceres.class = 'planet';
ceres.name = 'ceres';

%Ceres's property characteristics
prop = struct();
prop.mass = 9.393E20; %kg
prop.radius = 945*1000; %m

ceres.prop = prop;

%Ceres's display property characteristics
disp = struct();
disp.displaycol = [0.2,0.2,0.2];
disp.displaysphere = 1;
disp.displaycursor = 1;

ceres.disp = disp;

%Ceres's orbit properties
orbit = struct();
orbit.type = 'kepler_JPLmoon';
orbit.a = 2.7681116*AU;                    %m      Semi-maj Axis
orbit.e = 0.07575442;                        %ND     Eccentricity
orbit.inc = 10.59166*rad;                    %rad    inclination
orbit.lomega = 72.73329*rad;               %rad    arg of periapsis
orbit.Omega = 80.32180*rad;             %rad    long of asc. node
orbit.Omegadot = 0;      %rad/sec long of asc. node rate
orbit.M = 181.3812853*rad;                    %rad    mean anomaly
orbit.epoch = 57400+2400000.5; %Epoch (MJD) (JD)

ceres.orbit = orbit;

%Close Ceres definition and attach to tree
solarsys = amstree_attachobj(solarsys,ceres,'sun');

%%%%%%%%%%%%
%End: Ceres%
%%%%%%%%%%%%

%%%%%%%
%Vesta%
%%%%%%%

vesta = amstree_newtreeobj();
vesta.class = 'planet';
vesta.name = 'vesta';

%Vesta's property characteristics
prop = struct();
prop.mass = 2.590E20; %kg
prop.radius = 572*1000; %m

vesta.prop = prop;

%Vesta's display property characteristics
disp = struct();
disp.displaycol = [0.3,0.2,0.3];
disp.displaysphere = 1;
disp.displaycursor = 1;

vesta.disp = disp;

%Vesta's orbit properties
orbit = struct();
orbit.type = 'kepler_JPLmoon';
orbit.a = 2.3616695*AU;                    %m      Semi-maj Axis
orbit.e = 0.08892238;                        %ND     Eccentricity
orbit.inc = 7.14005*rad;                    %rad    inclination
orbit.lomega = 151.13759*rad;               %rad    arg of periapsis
orbit.Omega = 103.84606*rad;             %rad    long of asc. node
orbit.Omegadot = 0;      %rad/sec long of asc. node rate
orbit.M = 129.5297453*rad;                    %rad    mean anomaly
orbit.epoch = 57400+2400000.5; %Epoch (MJD) (JD)

vesta.orbit = orbit;

%Close Vesta definition and attach to tree
solarsys = amstree_attachobj(solarsys,vesta,'sun');

%%%%%%%%%%%%
%End: Vesta%
%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%
%%Post Processing%%
%%%%%%%%%%%%%%%%%%%

solarsys = amsorb_calcsauxprops(solarsys);


return