%Minimize transfer orbit objective function
%Inputs:
%r1 - initial position
%t1 - initial time (JD)
%oet - orbit elements of target orbit
%epoch - epoch of target orbit elements (JD)
%wt1 - weight of total delta-V objective
%wt2 - weight of target relative speed (norm(v2t - v2))
%wt3 - weight of time of flight objective (tof in days)
%mu - gravity constant of central body
%tof0 - intiial guess for time of flight (days) (optional)
%Outputs:
%r1 - intial position
%v1 - initial velocity
%r2 - final position
%v2 - final velocity
%tof - time of flight of minimum objective orbit
function [r1,v1,r2,v2,tof] = amsorb_minobjtrans_a(r1,t1,oet,epoch,wt1,wt2,wt3,mu,tof0)

if(nargin<9)
    app = oet.a;
    Tpp = pi*sqrt(app^3/mu);
    tof0 = Tpp; %initial guess of transit time as half the period of the target orbit
    tof0 = tof0/24/3600;
end




return

function obj = int_objective(tof,pars)

r1 = pars.r1;
t1 = pars.t1;
oet = pars.oet;
epoch = pars.epoch;
mu = pars.mu;

oett = amsorb_oe_to_oe_t(oet,(tof-epoch)*24*3600,mu);
[r2,v2] = amsorb_oe_to_rv(oett,mu);



return

function dodt = int_dobjdtof(tof,pars)


return