%Orbit element propagation in time
%Given:
%oe1 - orbit elements at initial time (L, angles)
%T - time to propagate mean anomaly (T)
%mu - gravitational constant of orbit (T^3/L^2)
%
%function oe2 = amsorb_oe_to_oe_t(oe1,T,mu)
function oe2 = amsorb_oe_to_oe_t(oe1,T,mu)

[r,v] = amsorb_oe_to_rv(oe1,mu);

if(abs(oe1.e) < 1)
    %UTOF problem seems unstable for large multiples of the orbit period
    %
    %Orbital period is going to be given by:
    TP = 2*pi*sqrt(oe1.a^3/mu);
    T = mod(T,TP); %subtracts multiples of the period
end

[r2,v2] = amsorb_UTOF(r,v,T,mu);
oe2 = amsorb_rv_to_oe(r2,v2,mu);

return