%Plots solar system
%solsys - solar system struct
%JD - epoch to plot solar system (Julian calendar date)
%fighandle: handle to figure to plot solsys objects in
%References display structures in solar system object for how to draw each
%feature
%Provide figure handle if you don't want to start a new figure
function amsorb_plotsolsys(solsys,JD,fighandle)

%Calculate planetary positions at epoch if it hasn't been done already
solsys = amsorb_solsysepochcalc(solsys,JD);

AU = 149597870700; %m in an AU

if(nargin<3)
    fighandle = figure(1);
    clf;
end

hold on;

gdisp = solsys.globaldisp;

for I = 1:size(solsys.objs,2)
    obj = solsys.objs{I};
    
    %draw each object's sphere
    radius = obj.prop.radius;
    r = obj.eprop.r;
    if(isfield(gdisp,'scale'))
        radius = radius*gdisp.scale;
    end
    
    if(isfield(obj.disp,'scale'))
        radius = radius*obj.disp.scale;
    end
    
    if(~isfield(obj.disp,'displaysphere'))
        obj.disp.displaysphere = 1;
    end
    dispyn = obj.disp.displaysphere;
    if(isfield(gdisp,'ovr_displaysphere'))
        dispyn = gdisp.ovr_displaysphere;
    end
    
    if(dispyn == 1)
        opt = struct();
        opt.alph = 1;
        opt.col = obj.disp.displaycol;
        ams_drawsphere(radius,r,opt);
    end
    
    %draw each object's cursor
    if(~isfield(obj.disp,'displaycursor'))
        obj.disp.displaycursor = 1;
    end
    if(obj.disp.displaycursor == 1)
        plot3(r(1),r(2),r(3),'o','Color',obj.disp.displaycol);
    end
    
    %if object has solsys.objs{I}.eprop.oe, then draw each object's orbit
    if(isfield(obj.eprop,'oe'))
        oe = obj.eprop.oe;
        mu = obj.prop.mu_parent;
        parent = obj.parent;
        rpar = solsys.objs{parent}.eprop.r;
        %[rx,ry,rz,rx0,ry0,rz0] = amsorb_traceorbit(oe,mu)
        [rx,ry,rz,rx0,ry0,rz0] = amsorb_traceorbit(oe,mu);
        rx = rx + rpar(1);
        ry = ry + rpar(2);
        rz = rz + rpar(3);
        plot3(rx,ry,rz,'-','Color',obj.disp.displaycol);
    end

end


%Do this later, after plotting at least one orbit
if(isfield(gdisp,'bgcolor'))
    set(fighandle,'Color',gdisp.bgcolor);
    fhc = get(fighandle,'Children');
    set(fhc,'Color',gdisp.bgcolor);
end
axis equal;


return