%Integrate and solve trajectory problem from fin.t0, fin.r0, fin.v0 to
%fin.vf
%
%
function outs = amsorb_top2_traj(optpars,ppars)

t0 = ppars.t0;
tf = ppars.tf;
r0 = ppars.r0;
v0 = ppars.v0;
rf = ppars.rf; %the target, not necessarily what will be acheived
vf = ppars.vf; %the target, not necessarily what will be acheived
mu = ppars.mu;
Nt = ppars.Nt; %number of time increments to use for integration
T = ppars.T; %thrust magnitude (acceleration at initial mass, m/sec^2)
Isp = ppars.Isp; %specific impulse (sec)
m = ppars.m0; %mass (fraction of initial mass)

tt0 = optpars.tt0; %time after start to stop initial burn
ttf = optpars.ttf; %time before finish to begin thrusting
azlst1 = optpars.azlst1; %thrust pointing list
ellst1 = optpars.ellst1;
azlst2 = optpars.azlst2;
ellst2 = optpars.ellst2;

tt0 = abs(tt0); %a hack, but maybe useful?
ttf = abs(ttf); 

%Just do Euler integration for now
t = t0;
dt = (tf-t0)/(Nt-1);
I = 1;
tlst(1) = 0;
r = r0;
v = v0;
rlst{1} = r;
vlst{1} = v;
aglst{1} = 0;
aulst{1} = 0;
plst{1} = 0;
mlst(1) = m;
bTlst(1) = 0;
tlst(1) = t;

dV = 0;
J2 = 0;

while(I<Nt)
    I = I + 1;
    t = t + dt;
    
    ag = -mu.*r./norm(r)^3;
    dm = 0;
    
    %work out orbital motion frame (not quite the same as Hill frame)
    %b1 = v0./norm(v0); %prograde vector
    %b3 = cross(r0,v0); %angular momentum vector
    %b3 = b3./norm(b3);
    %b2 = cross(b3,b1); %frame completion
    b1 = [1;0;0];
    b2 = [0;1;0];
    b3 = [0;0;1]; %Let's not make this complicated - just use the ecliptic inertial coordinates
    
    %work out if we are thrusting
    [p,bt,frac] = int_thrustdirection(azlst1,ellst1,azlst2,ellst2,tt0,ttf,t0,tf,t,b1,b2,b3,dt);
    %if we are thrusting
    if(bt~=0)
        au = p.*T./m.*frac;
        mdot = T/(Isp*9.8)*frac;
        dV = dV + norm(au)*dt;
        J2 = J2 + norm(au)^2*dt;
    else
        p = [0;0;0];
        au = [0;0;0];
        mdot = 0;
    end
    
    v = v+(au+ag).*dt;
    r = r+v.*dt;
    m = m - mdot*dt;
    
    %This is a kluge to fix when the coarseness of the timestep allows the
    %spacecraft mass to go negative:
    if(m<0)
        m = 0.01;
    end
    
    aulst{I} = au;
    aglst{I} = ag;
    plst{I} = p;
    mlst(I) = m;
    bTlst(I) = bt;
    rlst{I} = r;
    vlst{I} = v;
    tlst(I) = t;
end

outs.aulst = aulst;
outs.aglst = aglst;
outs.plst = plst;
outs.mlst = mlst;
outs.rlst = rlst;
outs.vlst = vlst;
outs.bTlst = bTlst;
outs.tlst = tlst;
outs.dV = dV;
outs.J2 = J2;

return

function [p,bt,frac] = int_thrustdirection(azlst1,ellst1,azlst2,ellst2,tt0,ttf,t0,tf,t,b1,b2,b3,dt)

p = [1;0;0];
bt = 0;
frac = 1;

if(t>=t0 && t<=t0+tt0-dt)
    t2_0 = t0;
    t2_f = t0+tt0;
    bt = 1;
    p = amsorb_top2_vinterp2(azlst1,ellst1,b1,b2,b3,t2_0,t2_f,t);
    frac = 1;
end

%within dt of cutoff
if(t>=t0+tt0-dt && t<=t0+tt0)
    t2_0 = t0;
    t2_f = t0+tt0;
    bt = 1;
    p = amsorb_top2_vinterp2(azlst1,ellst1,b1,b2,b3,t2_0,t2_f,t);
    frac = ((t0+tt0)-t)/dt;
end

%within dt of cutoff
if(t>=tf-ttf && t<=tf-ttf+dt)
    t2_0 = tf-ttf;
    t2_f = tf;
    bt = 1;
    p = amsorb_top2_vinterp2(azlst2,ellst2,b1,b2,b3,t2_0,t2_f,t);
    frac = (t-(tf-ttf))/dt;
end

if(t>=tf-ttf+dt && t<=tf)
    t2_0 = tf-ttf;
    t2_f = tf;
    bt = 1;
    p = amsorb_top2_vinterp2(azlst2,ellst2,b1,b2,b3,t2_0,t2_f,t);
    frac = 1;
end

p = p./norm(p);

return