%Delta-V cost of trajectory
function J = amsorb_top_fdv(rcv,fopt)
Np = fopt.Np; %number of control points
%dimension of rcv is ((Np-4)*3,1)
mu = fopt.mu; %sun gravitational parameter
tl = fopt.tl; %control point times list

rs = int_unspoolcontrol(rcv,Np,fopt); %control point coordinate cell array

%In counting up the control cost, count the control accelerations used
%before the last and after the first control spline. (First two points are
%fixed).

S1 = 0;
for I = 2:((Np-2))
    %interpolate initial and final velocity
    r0 = rs{I-1};
    r1 = rs{I};
    r2 = rs{I+1};
    r3 = rs{I+2};
    t0 = tl(I-1);
    t1 = tl(I);
    t2 = tl(I+1);
    t3 = tl(I+2);
    [v1,v2] = ams_splinevelinterp(r0,t0,r1,t1,r2,t2,r3,t3);

    %get spline coefficients
    [a0,a1,a2,a3] = ams_splinecoeff_v2(r1,v1.*(t2-t1),r2,v2.*(t2-t1));
    
    %get acceleration in center of spline
    [rc,vc,ac] = ams_splineinterp_v2(a0,a1,a2,a3,0.5*(t1+t2),t1,t2);
    
    %subtract the acceleration due to problem dynamics
    au = ac - int_fdyn(rc,mu);
    
    %integrate square of acceleration
    dt = t2-t1;
    S1 = S1 + norm(au).*dt;
    
end

J = S1;



return

function ad = int_fdyn(rc,mu)

ad = -mu.*rc./norm(rc)^3;

return

function rs = int_unspoolcontrol(rcv,N,fopt)
rs = {};

rs{1} = fopt.rc0; %first two control points are fixed by problem (position and velocity)
rs{2} = fopt.rc1;

for I = 3:(N-2)
    rs{I} = [rcv(3*(I-3)+1),rcv(3*(I-3)+2),rcv(3*(I-3)+3)]';
end

rs{N-1} = fopt.rcNm1; %last two control points are fixed (position and velocity)
rs{N} = fopt.rcN;

return