%Delta-V cost of trajectory
function stat = amsorb_top_solstat_v2(rcv,fopt)
Np = fopt.Np; %number of control points
%dimension of rcv is ((Np-4)*3,1)
mu = fopt.mu; %sun gravitational parameter
tl = fopt.tl; %control point times list

rs = int_unspoolcontrol(rcv,Np,fopt); %control point coordinate cell array

stat = struct();
stat.Np = Np;
stat.mu = mu;
stat.tl = tl;
stat.rc = rs;
ra = {};
au = {};
va = {};
ac = {};

%Version 2 - count the accelerations at the beginning and end of each
%spline (at each control point, instead of in the middle of each node)
%I suspect the hinges of the first and last segment allow the routine to sneak
%in a lot of uncounted acceleration. This should fix that.

S1 = 0;
for I = 2:((Np-2))
    %interpolate initial and final velocity
    r0 = rs{I-1};
    r1 = rs{I};
    r2 = rs{I+1};
    r3 = rs{I+2};
    t0 = tl(I-1);
    t1 = tl(I);
    t2 = tl(I+1);
    t3 = tl(I+2);
    
    t01 = 0.5*(t0+t1);
    t12 = 0.5*(t1+t2);
    t23 = 0.5*(t2+t3);
    dt1 = t12-t01;
    dt2 = t23-t12;
    
    [v1,v2] = ams_splinevelinterp(r0,t0,r1,t1,r2,t2,r3,t3);
    
    %get spline coefficients
    [a0,a1,a2,a3] = ams_splinecoeff_v2(r1,v1.*(t2-t1),r2,v2.*(t2-t1));
    
    %get acceleration in center of spline
    [rc1,vc1,ac1] = ams_splineinterp_v2(a0,a1,a2,a3,t1,t1,t2);
    [rc2,vc2,ac2] = ams_splineinterp_v2(a0,a1,a2,a3,t2,t1,t2);
    
    %subtract the acceleration due to problem dynamics
    au1 = ac1 - int_fdyn(rc1,mu);
    au2 = ac2 - int_fdyn(rc2,mu);
    ra{I-1} = r1;
    ra{I} = r2;
    au{I-1} = au1;
    au{I} = au2;
    ac{I-1} = ac1;
    ac{I} = ac2;
    va{I-1} = vc1;
    va{I} = vc2;
    
end
stat.au = au;
stat.ac = ac;
stat.ra = ra;
stat.va = va;

J = S1;



return

function ad = int_fdyn(rc,mu)

ad = -mu.*rc./norm(rc)^3;

return

function rs = int_unspoolcontrol(rcv,N,fopt)
rs = {};

rs{1} = fopt.rc0; %first two control points are fixed by problem (position and velocity)
rs{2} = fopt.rc1;

for I = 3:(N-2)
    rs{I} = [rcv(3*(I-3)+1),rcv(3*(I-3)+2),rcv(3*(I-3)+3)]';
end

rs{N-1} = fopt.rcNm1; %last two control points are fixed (position and velocity)
rs{N} = fopt.rcN;

return