%Provides orbit trace to upstream drawing functions
%
%function [rx,ry,rz,rx0,ry0,rz0] = amsorb_traceorbit(oe,mu)
function [rx,ry,rz,rx0,ry0,rz0] = amsorb_traceorbit(oe,mu)

if(oe.e < 1)
    nuecrit = -1;
    nuebnd = pi;
else
    nuecrit = acos(-1/oe.e);
    nuebnd = 0.9*nuecrit;
end

nl = linspace(-nuebnd,nuebnd,100);
rm = zeros(1,size(nl,2));

if(~isfield(oe,'p'))
    if(~isfield(oe,'a'))
        fprintf('Orbit does not have a or p specified! Error!\n');
        return;
    else
        oe.p = oe.a*(1-oe.e^2);
    end
end

for I = 1:size(nl,2)
    rm(I) = oe.p/(1+oe.e*cos(nl(I)));
end

r0 = oe.p/(1+oe.e*cos(oe.nue));

%Get orbit frame
   inc = oe.inc;
   Om = oe.Omega;
   A = [1,0,0;0,cos(inc),-sin(inc);0,sin(inc),cos(inc)];
   B = [cos(Om),-sin(Om),0;sin(Om),cos(Om),0;0,0,1];
   C = B*A;
   un = C(:,1);     %line of nodes
   unp = C(:,2);    %complement orbit plane vector
   uh = C(:,3);     %angular momentum unit vector


   lom = oe.lomega;
   nue = oe.nue;
   
   ue = cos(lom).*un + sin(lom).*unp;   %eccentricity unit vector
   up = -sin(lom).*un + cos(lom).*unp;  %semi-latus-rectum unit vector
    ur = cos(lom+nue).*un + sin(lom+nue).*unp;
   unue = cross(uh,ur);

for I = 1:size(nl,2)
    nue = nl(I);
    ur = cos(lom+nue).*un + sin(lom+nue).*unp;
    rx(I) = rm(I).*ur(1);
    ry(I) = rm(I).*ur(2);
    rz(I) = rm(I).*ur(3);
end
    nue = oe.nue;
    ur = cos(lom+nue).*un + sin(lom+nue).*unp;
    rx0 = r0.*ur(1);
    ry0 = r0.*ur(2);
    rz0 = r0.*ur(3);

hold on;
%plot3(rx,ry,rz,'Color',color);
%plot3(rx0,ry0,rz0,'o','Color',color);

return;