clc; clear all;
path(path,'../ConstrainedOpt_Matlab');

Fname = 'LowThrustStats2';

G = 6.67408E-11; %N-m^2/kg^2
AU = 149597870700; %m in an AU
cty = 100*365.25*24*3600; %sec in a century
rad = pi/180; %conv deg to radians
day = 24*3600; %sec in a day

%I. Set Departure and Arrival Dates
JD0 = ams_juliandate(2022,08,1,0,0,0);
JDf0 = ams_juliandate(2022,11,1,0,0,0);
JDff = ams_juliandate(2024,12,1,0,0,0);

JDf_lst = linspace(JDf0,JDff,40);

dV_lst1 = [];
J2_lst1 = [];
dV_lst2 = [];
J2_lst2 = [];
val_lst1 = [];
val_lst2 = [];
mf_lst1 = [];
mf_lst2 = [];

rel_lst1 = [];
vel_lst1 = [];
rel_lst2 = [];
vel_lst2 = [];

outs_lst1 = {};
outs_lst2 = {};
opts_lst1 = {};
opts_lst2 = {};


Isp = 3000;         %sec Isp
Ttarg1 = 1/1000;    %mm/sec^2
Ttarg2 = 0.5/1000;


for I = 1:size(JDf_lst,2)
    JDf = JDf_lst(I);
    
    dt1 = ams_JD_to_str(JD0,1);
    dt2 = ams_JD_to_str(JDf,1);
    
    fprintf('\n\nRunning case %d for %s to %s\n\n',I,dt1,dt2);
    
    [outs1,opts1,rel1,vel1,outs2,opts2,rel2,vel2] = scriptfunc_EMlowthrust(JD0,JDf,Ttarg1,Ttarg2,Isp)
    
    outs_lst1{I} = outs1;
    opts_lst1{I} = opts1;
    dV_lst1(I) = outs1.dV;
    J2_lst1(I) = outs1.J2;
    mf_lst1(I) = outs1.mlst(end);
    rel_lst1(I) = rel1;
    vel_lst1(I) = vel1;
    if(rel1 < 0.02 && vel1 < 0.05)
        val_lst1(I) = 1;
    else
        val_lst1(I) = 0;
    end
       
    outs_lst2{I} = outs2;
    opts_lst2{I} = opts2;
    dV_lst2(I) = outs2.dV;
    J2_lst2(I) = outs2.J2;
    mf_lst2(I) = outs2.mlst(end);
    rel_lst2(I) = rel2;
    vel_lst2(I) = vel2;
    if(rel2 < 0.02 && vel2 < 0.05)
        val_lst2(I) = 1;
    else
        val_lst2(I) = 0;
    end
    
    fprintf('%1.6g %% complete..\n',I/size(JDf_lst,2)*100);
    save(Fname);
end

save(Fname);