%Vesta to Ceres transfer arc: Verification problem
%Dawn departed Vesta on May 2012
%Dawn arrived at Ceres on August 2015
%Dawn has 3 NSTAR engines, each capable of producing 92 mN
%of thrust. It weights 1240 kg, wet, in terms of initial mass
%and has 450 kg of xenon propellant
%--> Initial acceleration capability of 0.22 mm/sec^2
%--> Dry acceleration capability of 0.349 mm/sec^2

function [outs1,opts1,rel1,vel1,outs2,opts2,rel2,vel2] = scriptfunc_EMlowthrustb(JD0,JDf,Ttarg1,Ttarg2,Isp)

%clc; clear all;
path(path,'../ConstrainedOpt_Matlab');

G = 6.67408E-11; %N-m^2/kg^2
AU = 149597870700; %m in an AU
cty = 100*365.25*24*3600; %sec in a century
rad = pi/180; %conv deg to radians
day = 24*3600; %sec in a day

%I. Set Departure and Arrival Dates
%JD0 = ams_juliandate(2012,05,1,0,0,0);
%JDf = ams_juliandate(2015,08,1,0,0,0);
t0 = JD0*3600*24;
tf = JDf*3600*24;

%II. Get Solsystem Model
SS = amsorb_generatesolarsys();
mu_sol = SS.objs{1}.prop.mu;

%III. Get Initial and Final Coordinates
SS0 = amsorb_solsysepochcalc(SS,JD0);
SSf = amsorb_solsysepochcalc(SS,JDf);

o1 = amstree_getindex(SS0,'earth');
o2 = amstree_getindex(SSf,'mars');
r0 = SS0.objs{o1}.eprop.r;
v0 = SS0.objs{o1}.eprop.v;
rf = SSf.objs{o2}.eprop.r;
vf = SSf.objs{o2}.eprop.v;

%IV. Setup problem parameters
ppars.t0 = t0;
ppars.tf = tf;
ppars.r0 = r0;
ppars.v0 = v0;
ppars.rf = rf; %the target, not necessarily what will be acheived
ppars.vf = vf; %the target, not necessarily what will be acheived
ppars.mu = mu_sol;
ppars.Nt = 400; %number of time increments to use for integration
ppars.Nazel = 4; %number of azimuth/elevation control points to use
ppars.T = Ttarg1; %thrust magnitude (acceleration at initial mass, m/sec^2)
ppars.Isp = Isp; %specific impulse (sec)
ppars.m0 = 1; %mass (fraction of initial mass at start of arc)

%V. Get initial optimization parameter struct
optpars = ams_top2_gen_ics(ppars);
z0 = amsorb_top2_unspool_z(optpars,t0,tf);

%VI. Optimize optimization parameters with constrained optimization problem
%VI. Constrained Newton Optimization Paramters
solpars = struct();
solpars.verbose = 2; %Display progress
solpars.maxiter = 300; %120
solpars.dx = 1E-5;
solpars.vtol = 1E-15;
solpars.ctol = 1E-30;
solpars.use_reltol = 0;
solpars.reltol = 1E-15;
solpars.use_alphastep = 1;
solpars.alpha = 0.2;

ppars.cnstscale = 1E2;
fobj = @amsorb_top2_fobj_2b;

J0 = fobj(z0,ppars);
out0 = amsorb_top2_traj(optpars,ppars);

%Initial solution statistics
%fprintf('Initial solution stats:\n');
%fprintf('dV = %1.6g m/sec J2 = %1.6g m^2/sec^3\n', out0.dV, out0.J2);
%re0 = norm(out0.rlst{end}-rf);
%ve0 = norm(out0.vlst{end}-vf);
%fprintf('R_error = %1.6g m, %1.6g%%\n',re0,re0/norm(rf)*100);
%fprintf('V_error = %1.6g m/sec, %1.6g%%\n',ve0,ve0/norm(vf)*100);

N = size(z0,1);

[zs,valid] = amsopt_cgls(fobj,z0,ppars,N,solpars);

opts1 = amsorb_top2_spool_z(zs,t0,tf);
outs1 = amsorb_top2_traj(opts1,ppars);

rel1 = norm(outs1.rlst{end}-rf)/norm(rf);
vel1 = norm(outs1.vlst{end}-vf)/norm(vf);

z0 = zs;

ppars.T = Ttarg2;

[zs,valid] = amsopt_cgls(fobj,z0,ppars,N,solpars);

opts2 = amsorb_top2_spool_z(zs,t0,tf);
outs2 = amsorb_top2_traj(opts2,ppars);

rel2 = norm(outs2.rlst{end}-rf)/norm(rf);
vel2 = norm(outs2.vlst{end}-vf)/norm(vf);

%Initial solution statistics
%fprintf('Initial solution stats:\n');
%fprintf('dV = %1.6g m/sec J2 = %1.6g m^2/sec^3\n', out0.dV, out0.J2);
%re0 = norm(out0.rlst{end}-rf);
%ve0 = norm(out0.vlst{end}-vf);
%fprintf('R_error = %1.6g m, %1.6g%%\n',re0,re0/norm(rf)*100);
%fprintf('V_error = %1.6g m/sec, %1.6g%%\n',ve0,ve0/norm(vf)*100);
%Optimized solution statistics
%fprintf('Optimized solution stats:\n');
%fprintf('dV = %1.6g m/sec J2 = %1.6g m^2/sec^3\n', outs.dV, outs.J2);
%res = norm(outs.rlst{end}-rf);
%ves = norm(outs.vlst{end}-vf);
%fprintf('R_error = %1.6g m, %1.6g%%\n',res,res/norm(rf)*100);
%fprintf('V_error = %1.6g m/sec, %1.6g%%\n',ves,ves/norm(vf)*100);

return