function [deltaV, valid] = scriptfunc_earthmars(JD0,JDf)
%Solve the Earth-Mars
%clc; clear all;
path(path,'../ConstrainedOpt_Matlab');

G = 6.67408E-11; %N-m^2/kg^2
AU = 149597870700; %m in an AU
cty = 100*365.25*24*3600; %sec in a century
rad = pi/180; %conv deg to radians
day = 24*3600; %sec in a day

%I. Set Departure and Arrival Dates
%JD0 = ams_juliandate(2012,05,1,0,0,0);
%JDf = ams_juliandate(2015,08,1,0,0,0);
t0 = JD0*3600*24;
tf = JDf*3600*24;

%II. Get Solsystem Model
SS = amsorb_generatesolarsys();
mu_sol = SS.objs{1}.prop.mu;

%III. Get Initial and Final Coordinates
SS0 = amsorb_solsysepochcalc(SS,JD0);
SSf = amsorb_solsysepochcalc(SS,JDf);

o1 = amstree_getindex(SS0,'earth');
o2 = amstree_getindex(SSf,'mars');
r0 = SS0.objs{o1}.eprop.r;
v0 = SS0.objs{o1}.eprop.v;
rf = SSf.objs{o2}.eprop.r;
vf = SSf.objs{o2}.eprop.v;

[v1_sw, v2_sw, v1_lw, v2_lw, valid] = amsorb_Gaussp_b(r0,rf,(tf-t0),mu_sol);

dv1 = norm(v1_sw-v0)+norm(v2_sw-vf);
dv2 = norm(v1_lw-v0)+norm(v2_lw-vf);
if(dv1<dv2)
    deltaV = dv1;
else
    deltaV = dv2;
end

return