clc; clear all;

G = 6.67408E-11; %N-m^2/kg^2
AU = 149597870700; %m in an AU
cty = 100*365.25*24*3600; %sec in a century
rad = pi/180; %conv deg to radians
day = 24*3600; %sec in a day

ss = amsorb_generatesolarsys();

Tdep = 2459826;
Tarr = 2460179;

%JD = ams_juliandate(2018,2,22,0,0,0); %center date for porkchop plot
JD = Tdep;
ss = amsorb_solsysepochcalc(ss,JD);



fprintf('name:\t\trsoi (radii)\t\trsoi (Mm)\n');
for I = 1:size(ss.objs,2)
    if(isfield(ss.objs{I}.eprop,'rsoi'))
        rsoi = ss.objs{I}.eprop.rsoi;
        r = ss.objs{I}.prop.radius;
        fprintf('%s:\t\t%1.0f\t\t%1.0f Mm\n',ss.objs{I}.name,...
            rsoi/r,rsoi/1E6);
    end
end

mu = ss.objs{4}.prop.mu_parent;
oe1 = ss.objs{4}.eprop.oe;
oe2 = ss.objs{5}.eprop.oe;
t0 = ss.objs{4}.eprop.epoch;

Ts = amsorb_synodicperiod(oe1,oe2,mu); %synodic period in seconds
%Get hohman tof
a12 = 0.5*(oe1.a+oe2.a);
Th = sqrt(a12^3/mu)*pi; %center height for hohman plot

%t limits (JulianDates)
t1 = Tdep;
t2 = Tarr;
%function [r1,v1,r2,v2,is_sw,dv1,dv2] = amsorb_oe_to_oe_intercept(oe1,epoch1,t1,oe2,epoch2,t2,mu)
[r1,v1,r2,v2,is_sw,dv1,dv2] = amsorb_oe_to_oe_intercept(oe1,t0,t1,oe2,t0,t2,mu);


fh = figure(1)
clf; hold on;
amsorb_plotsolsys(ss,JD,fh);
ams_draworbitarc_rvt(r1,v1,(t2-t1)*3600*24,mu,[0,1,0]);
NAU = 3;
axis([-NAU*AU,NAU*AU,-NAU*AU,NAU*AU,-NAU*AU,NAU*AU]);
fhc = get(fh,'Children');
set(fhc,'XColor',[0,1,0]);
set(fhc,'YColor',[0,1,0]);
set(fhc,'ZColor',[0,1,0]);
xlabel('x (m)');
ylabel('y (m)');
zlabel('z (m)');
dtstr = ams_JD_to_str(JD);
th = text(-NAU*AU*0.8,-NAU*AU*0.8,-NAU*AU*0.8,dtstr);
set(th,'Color',[0,1,0]);
