clc; clear all;

ss = amsorb_generatesolarsys();

JD = ams_juliandate(2016,2,22,0,0,0); %center date for porkchop plot
ss = amsorb_solsysepochcalc(ss,JD);

fprintf('name:\t\trsoi (radii)\t\trsoi (Mm)\n');
for I = 1:size(ss.objs,2)
    if(isfield(ss.objs{I}.eprop,'rsoi'))
        rsoi = ss.objs{I}.eprop.rsoi;
        r = ss.objs{I}.prop.radius;
        fprintf('%s:\t\t%1.0f\t\t%1.0f Mm\n',ss.objs{I}.name,...
            rsoi/r,rsoi/1E6);
    end
end

mu = ss.objs{4}.prop.mu_parent;
oe1 = ss.objs{4}.eprop.oe;
oe2 = ss.objs{5}.eprop.oe;
t0 = ss.objs{4}.eprop.epoch;

Ts = amsorb_synodicperiod(oe1,oe2,mu); %synodic period in seconds
%Get hohman tof
a12 = 0.5*(oe1.a+oe2.a);
Th = sqrt(a12^3/mu)*pi; %center height for hohman plot

%t limits (JulianDates)
t1_1 = t0-Ts/2/3600/24;
t1_2 = t0+Ts/2/3600/24;
t2_1 = t0+(0)/3600/24;
t2_2 = t0+(1.50*Th+Ts)/3600/24;

fprintf('%s - %s \n',ams_JD_to_str(t1_1),ams_JD_to_str(t1_2));
fprintf('%s - %s \n',ams_JD_to_str(t2_1),ams_JD_to_str(t2_2));

Nt1 = 30;
Nt2 = 30;

[t1,t2,r1,v1,r2,v2,is_sw,dv1,dv2] = amsorb_porkchopproblem(oe1,t0,t1_1,t1_2,Nt1,oe2,t0,t2_1,t2_2,Nt2,mu,1)

f1h = figure(1)
clf; hold on;
contourf(t1,t2,dv1+dv2,[0:1000:20000]);
a1h = get(f1h,'CurrentAxes');
XTick = get(a1h,'XTick');
YTick = get(a1h,'YTick');
for I = 1:size(XTick,2)
    if(mod(I,2)==1)
        XTL{I} = ams_JD_to_str(XTick(I),1);
    else
        XTL{I} = '';
    end
end
for I = 1:size(YTick,2)
    YTL{I} = ams_JD_to_str(YTick(I),1);
end
set(a1h,'XTickLabel',XTL);
set(a1h,'YTickLabel',YTL);

figure(2)
clf; hold on;
contourf(t1,t2,is_sw);