%Create a trimesh for a sphere
%
%[tri,x,y,z] = ams_createspheretri(r,x0,y0,z0,Nphi,Nthet)
%r - radius
%x0,y0,z0 - center location
%Nphi - number of longtitude points (must be > 2)
%Ntheta - number of lattitude points (must be >2)
function [tri,x,y,z] = ams_createspheretri(r,x0,y0,z0,Nphi,Nthet)

tri = [];

%top
x(1) = x0+(r*sin(0)*cos(0));
y(1) = y0+(r*sin(0)*sin(0));
z(1) = z0+(r*cos(0));

%rings
for I = 1:Nphi
    for J = 1:Nthet
		phi = pi/(Nphi+1)*(I);
		th = 2*pi/(Nthet)*J;

        x(int_mapij(I,J,Nthet)) = x0+(r*sin(phi)*cos(th));
		y(int_mapij(I,J,Nthet)) = y0+(r*sin(phi)*sin(th));
		z(int_mapij(I,J,Nthet)) = z0+(r*cos(phi));
    end
end

%Setup the Triangle Mesh
ND = int_mapij(Nphi,Nthet,Nthet)+1;
%bottom
x(ND) = x0+(r*sin(pi)*cos(0));
y(ND) = y0+(r*sin(pi)*sin(0));
z(ND) = z0+(r*cos(pi));

%top
II = 1;
for I = 1:Nthet
    tri(II,:) = [1, int_mapij(1,I,Nthet), int_mapij(1,I+1,Nthet)];
    II = II + 1;
end
%middle
for I = 1:Nphi-1
    for J = 1:Nthet
        tri(II,:) = [int_mapij(I,J,Nthet), int_mapij(I+1,J,Nthet), int_mapij(I,J+1,Nthet)];
        II = II + 1;
        tri(II,:) = [int_mapij(I,J+1,Nthet), int_mapij(I+1,J,Nthet), int_mapij(I+1,J+1,Nthet)];
        II = II + 1;
    end
end
%bottom
for I = 1:Nthet
    tri(II,:) = [int_mapij(Nphi,I,Nthet), ND, int_mapij(Nphi,I+1,Nthet)];
    II = II + 1;
end

return
%%%%END MAIN FUNCTION %%%%

function K = int_mapij(I,J,NN)
if(J>=NN+1)
    J = J - NN;
end
K = 2+(I-1)*NN+(J-1);
return
