%Draws a sphere of the specified radius at the specified x,y,z location
%radius - the sphere's radius
%rvec - column vector with center location of the sphere
%opt - optional option struct
%   opt.col - color vector;
%   opt.Nphi - number of lattitude lines (default 9)
%   opt.Nthet - number of longitude lines (default 18)
%   opt.RMat - 3x3 rotation matrix applied to sphere (so that poles/equator
%   appear in the right orientation) - default identity
%   opt.alph - alpha of shape
%function ams_drawsphere(radius, rvec, opt)
function ams_drawsphere(radius, rvec, opt)

defopt = struct();
defopt.col = [0.5,0.5,0.5];
defopt.Nphi = 9;
defopt.Nthet = 18;
defopt.RMat = eye(3,3);

if(nargin<=2)
    opt = defopt;
else
    if(~isfield(opt,'col'))
        opt.col = [0.5,0.5,0.5];
    end
    if(~isfield(opt,'Nphi'))
        opt.Nphi = 9;
    end
    if(~isfield(opt,'Nthet'))
        opt.Nthet = 18;
    end
    if(~isfield(opt,'RMat'))
        opt.RMat = eye(3,3);
    end
    if(~isfield(opt,'alph'))
        opt.alph = 1.0;
    end
end

[tri,x,y,z] = ams_createspheretri(radius,0,0,0,opt.Nphi,opt.Nthet);
for I = 1:size(x,2)
    rr = [x(I),y(I),z(I)]';
    rr2 = opt.RMat*rr;
    x(I) = rr2(1)+rvec(1);
    y(I) = rr2(2)+rvec(2);
    z(I) = rr2(3)+rvec(3);
end
ams_drawmesh(tri,x,y,z,opt.col,opt.alph);

return